@@ -1,7 +1,7 @@
 #!/usr/local/bin/perl
 ##--------------------------------------------------------------------------##
 ##  File:
-##      $Id: install.pl,v 1.6 2002/09/29 04:23:26 ehood Exp $
+##      $Id: install.pl,v 1.7 2003/04/08 03:39:40 ehood Exp $
 ##  Description:
 ##      See POD below or run program with -man option.
 ##--------------------------------------------------------------------------##
@@ -534,11 +534,14 @@ sub find_mknmz {
 sub find_namazu_cgi {
   print qq/Looking for 'namazu.cgi'.../  if $Verbose;
   my($p, $cgi);
-  foreach $p (qw( /usr/local/libexec
+  foreach $p (join('/', $ENV{'HOME'}, 'libexec'),
+	      qw( /usr/local/libexec
 		  /usr/local/namazu/libexec
 		  /usr/libexec
 		  /usr/namazu/libexec
 		  /var/www/cgi-bin
+		  /usr/lib/cgi-bin
+		  /usr/local/lib/cgi-bin
 		  /home/httpd/cgi-bin )) {
     $cgi = "$p/namazu.cgi";
     last  if (-x $cgi);
@@ -808,7 +811,7 @@ are not automatically performed by this program.
 
 =head1 VERSION
 
-$Id: install.pl,v 1.6 2002/09/29 04:23:26 ehood Exp $
+$Id: install.pl,v 1.7 2003/04/08 03:39:40 ehood Exp $
 
 =head1 AUTHOR
 
